@@ -1,4 +1,4 @@
-/*  Copyright (c) 2003-2013 Xfce Development Team
+/*  Copyright (c) 2003-2014 Xfce Development Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,16 +63,16 @@ lnk_clicked(GtkTextTag *tag,
  * unit, use LRM (left-to-right mark) etc. to align it properly with
  * its numeric value.
  */
-#define APPEND_TEXT_ITEM(text, item)                            \
-    rawvalue = get_data(conditions, data->units, item,          \
-                        FALSE, data->night_time);               \
-    unit = get_unit(data->units, item);                         \
-    value = g_strdup_printf(_("\t%s%s%s%s%s\n"),                \
-                            text, text ? ": " : "",             \
-                            rawvalue,                           \
-                            strcmp(unit, "°") ? " " : "",       \
-                            unit);                              \
-    g_free(rawvalue);                                           \
+#define APPEND_TEXT_ITEM(text, item)                        \
+    rawvalue = get_data(conditions, data->units, item,      \
+                        FALSE, data->night_time);           \
+    unit = get_unit(data->units, item);                     \
+    value = g_strdup_printf(_("\t%s%s%s%s%s\n"),            \
+                            text, text ? ": " : "",         \
+                            rawvalue,                       \
+                            strcmp(unit, "°") ? " " : "",   \
+                            unit);                          \
+    g_free(rawvalue);                                       \
     APPEND_TEXT_ITEM_REAL(value);
 
 #define APPEND_LINK_ITEM(prefix, text, url, lnk_tag)                    \
@@ -378,6 +378,16 @@ create_summary_tab(plugin_data *data)
     g_free(next_download);
     APPEND_TEXT_ITEM_REAL(value);
 
+    /* Check for deprecated API and issue a warning if necessary */
+    if (data->weather_update->http_status_code == 203)
+        APPEND_BTEXT
+            (_("\tMet.no LocationforecastLTS API states that this version\n"
+               "\tof the webservice is deprecated, and the plugin needs to be\n"
+               "\tadapted to use a newer version, or it will stop working within\n"
+               "\ta few months.\n"
+               "\tPlease file a bug on https://bugzilla.xfce.org if no one\n"
+               "\telse has done so yet.\n\n"));
+
     last_download = format_date(data->astro_update->last, NULL, TRUE);
     next_download = format_date(data->astro_update->next, NULL, TRUE);
     value = g_strdup_printf(_("\tAstronomical data:\n"
@@ -391,6 +401,15 @@ create_summary_tab(plugin_data *data)
     g_free(next_download);
     APPEND_TEXT_ITEM_REAL(value);
 
+    /* Check for deprecated sunrise API and issue a warning if necessary */
+    if (data->astro_update->http_status_code == 203)
+        APPEND_BTEXT
+            (_("\n\tMet.no sunrise API states that this version of the webservice\n"
+               "\tis deprecated, and the plugin needs to be adapted to use\n"
+               "\ta newer version, or it will stop working within a few months.\n"
+               "\tPlease file a bug on https://bugzilla.xfce.org if no one\n"
+               "\telse has done so yet.\n"));
+
     /* calculation times */
     APPEND_BTEXT(_("\nTimes Used for Calculations\n"));
     point = format_date(conditions->point, NULL, TRUE);
@@ -416,48 +435,48 @@ create_summary_tab(plugin_data *data)
 
     /* sun and moon */
     APPEND_BTEXT(_("\nAstronomical Data\n"));
-    if (data->astrodata) {
-        if (data->astrodata->sun_never_rises) {
+    if (data->current_astro) {
+        if (data->current_astro->sun_never_rises) {
             value = g_strdup(_("\tSunrise:\t\tThe sun never rises today.\n"));
             APPEND_TEXT_ITEM_REAL(value);
-        } else if (data->astrodata->sun_never_sets) {
+        } else if (data->current_astro->sun_never_sets) {
             value = g_strdup(_("\tSunset:\t\tThe sun never sets today.\n"));
             APPEND_TEXT_ITEM_REAL(value);
         } else {
-            sunrise = format_date(data->astrodata->sunrise, NULL, TRUE);
+            sunrise = format_date(data->current_astro->sunrise, NULL, TRUE);
             value = g_strdup_printf(_("\tSunrise:\t\t%s\n"), sunrise);
             g_free(sunrise);
             APPEND_TEXT_ITEM_REAL(value);
 
-            sunset = format_date(data->astrodata->sunset, NULL, TRUE);
+            sunset = format_date(data->current_astro->sunset, NULL, TRUE);
             value = g_strdup_printf(_("\tSunset:\t\t%s\n\n"), sunset);
             g_free(sunset);
             APPEND_TEXT_ITEM_REAL(value);
         }
 
-        if (data->astrodata->moon_phase)
+        if (data->current_astro->moon_phase)
             value = g_strdup_printf(_("\tMoon phase:\t%s\n"),
                                     translate_moon_phase
-                                    (data->astrodata->moon_phase));
+                                    (data->current_astro->moon_phase));
         else
             value = g_strdup(_("\tMoon phase:\tUnknown\n"));
         APPEND_TEXT_ITEM_REAL(value);
 
-        if (data->astrodata->moon_never_rises) {
+        if (data->current_astro->moon_never_rises) {
             value =
                 g_strdup(_("\tMoonrise:\tThe moon never rises today.\n"));
             APPEND_TEXT_ITEM_REAL(value);
-        } else if (data->astrodata->moon_never_sets) {
+        } else if (data->current_astro->moon_never_sets) {
             value =
                 g_strdup(_("\tMoonset:\tThe moon never sets today.\n"));
             APPEND_TEXT_ITEM_REAL(value);
         } else {
-            moonrise = format_date(data->astrodata->moonrise, NULL, TRUE);
+            moonrise = format_date(data->current_astro->moonrise, NULL, TRUE);
             value = g_strdup_printf(_("\tMoonrise:\t%s\n"), moonrise);
             g_free(moonrise);
             APPEND_TEXT_ITEM_REAL(value);
 
-            moonset = format_date(data->astrodata->moonset, NULL, TRUE);
+            moonset = format_date(data->current_astro->moonset, NULL, TRUE);
             value = g_strdup_printf(_("\tMoonset:\t%s\n"), moonset);
             g_free(moonset);
             APPEND_TEXT_ITEM_REAL(value);
@@ -487,14 +506,11 @@ create_summary_tab(plugin_data *data)
     g_free(wind);
     APPEND_TEXT_ITEM_REAL(value);
 
-    rawvalue = get_data(conditions, data->units, WIND_DIRECTION,
-                        FALSE, data->night_time);
-    wind = translate_wind_direction(rawvalue);
-    g_free(rawvalue);
+    /* wind direction */
     rawvalue = get_data(conditions, data->units, WIND_DIRECTION_DEG,
                         FALSE, data->night_time);
-
-    /* wind direction */
+    wind = get_data(conditions, data->units, WIND_DIRECTION,
+                        FALSE, data->night_time);
     value = g_strdup_printf(_("\tDirection: %s (%s%s)\n"),
                             wind, rawvalue,
                             get_unit(data->units, WIND_DIRECTION_DEG));
@@ -503,8 +519,8 @@ create_summary_tab(plugin_data *data)
     APPEND_TEXT_ITEM_REAL(value);
 
     /* precipitation */
-    APPEND_BTEXT(_("\nPrecipitations\n"));
-    APPEND_TEXT_ITEM(_("Precipitations amount"), PRECIPITATIONS);
+    APPEND_BTEXT(_("\nPrecipitation\n"));
+    APPEND_TEXT_ITEM(_("Precipitation amount"), PRECIPITATION);
 
     /* atmosphere */
     APPEND_BTEXT(_("\nAtmosphere\n"));
@@ -610,7 +626,7 @@ forecast_cell_get_tooltip_text(plugin_data *data,
        align the values; Monospace font is enforced with <tt> tags for
        alignment, and the text is enclosed in <small> tags because
        that looks much better and saves space.
-     */
+    */
     text = g_string_new(_("<b>Times used for calculations</b>\n"));
     value = format_date(fcdata->start, NULL, TRUE);
     g_string_append_printf(text, _("<tt><small>"
@@ -651,11 +667,11 @@ forecast_cell_get_tooltip_text(plugin_data *data,
                           "</small></tt>\n\n"),
                         HUMIDITY);
 
-    g_string_append(text, _("<b>Precipitations</b>\n"));
+    g_string_append(text, _("<b>Precipitation</b>\n"));
     APPEND_TOOLTIP_ITEM(_("<tt><small>"
                           "Amount:        %s%s%s"
                           "</small></tt>\n\n"),
-                        PRECIPITATIONS);
+                        PRECIPITATION);
 
     g_string_append(text, _("<b>Clouds</b>\n"));
     /* TRANSLATORS: Clouds percentages are aligned to the right in the
@@ -684,6 +700,87 @@ forecast_cell_get_tooltip_text(plugin_data *data,
 }
 
 
+static gchar *
+forecast_day_header_tooltip_text(xml_astro *astro)
+{
+    GString *text;
+    gchar *result, *day, *sunrise, *sunset, *moonrise, *moonset;
+
+    /* TRANSLATORS: Please use spaces as needed or desired to properly
+       align the values; Monospace font is enforced with <tt> tags for
+       alignment, and the text is enclosed in <small> tags because
+       that looks much better and saves space.
+    */
+
+    text = g_string_new("");
+    if (astro) {
+        day = format_date(astro->day, "%Y-%m-%d", TRUE);
+        g_string_append_printf(text, _("<b>%s</b>\n"), day);
+        g_free(day);
+
+        if (astro->sun_never_rises)
+            g_string_append(text, _("<tt><small>"
+                                    "Sunrise: The sun never rises this day."
+                                    "</small></tt>\n"));
+        else if (astro->sun_never_sets)
+            g_string_append(text, _("<tt><small>"
+                                    "Sunset: The sun never sets this day."
+                                    "</small></tt>\n"));
+        else {
+            sunrise = format_date(astro->sunrise, NULL, TRUE);
+            g_string_append_printf(text, _("<tt><small>"
+                                           "Sunrise: %s"
+                                           "</small></tt>\n"), sunrise);
+            g_free(sunrise);
+
+            sunset = format_date(astro->sunset, NULL, TRUE);
+            g_string_append_printf(text, _("<tt><small>"
+                                           "Sunset:  %s"
+                                           "</small></tt>\n\n"), sunset);
+            g_free(sunset);
+        }
+
+        if (astro->moon_phase)
+            g_string_append_printf(text, _("<tt><small>"
+                                           "Moon phase: %s"
+                                           "</small></tt>\n"),
+                                   translate_moon_phase(astro->moon_phase));
+        else
+            g_string_append(text, _("<tt><small>"
+                                    "Moon phase: Unknown"
+                                    "</small></tt>\n"));
+
+        if (astro->moon_never_rises)
+            g_string_append(text, _("<tt><small>"
+                                    "Moonrise: The moon never rises this day."
+                                    "</small></tt>\n"));
+        else if (astro->moon_never_sets)
+            g_string_append(text,
+                            _("<tt><small>"
+                              "Moonset: The moon never sets this day."
+                              "</small></tt>\n"));
+        else {
+            moonrise = format_date(astro->moonrise, NULL, TRUE);
+            g_string_append_printf(text, _("<tt><small>"
+                                           "Moonrise: %s"
+                                           "</small></tt>\n"), moonrise);
+            g_free(moonrise);
+
+            moonset = format_date(astro->moonset, NULL, TRUE);
+            g_string_append_printf(text, _("<tt><small>"
+                                           "Moonset:  %s"
+                                           "</small></tt>"), moonset);
+            g_free(moonset);
+        }
+    }
+
+    /* Free GString only and return its character data */
+    result = text->str;
+    g_string_free(text, FALSE);
+    return result;
+}
+
+
 static GtkWidget *
 wrap_forecast_cell(const GtkWidget *widget,
                    const GdkColor *color)
@@ -785,16 +882,14 @@ add_forecast_cell(plugin_data *data,
     g_free(value);
 
     /* wind direction and speed */
-    rawvalue = get_data(fcdata, data->units, WIND_DIRECTION,
-                        FALSE, data->night_time);
-    wind_direction = translate_wind_direction(rawvalue);
+    wind_direction = get_data(fcdata, data->units, WIND_DIRECTION,
+                              FALSE, data->night_time);
     wind_speed = get_data(fcdata, data->units, WIND_SPEED,
                           data->round, data->night_time);
     value = g_strdup_printf("%s %s %s", wind_direction, wind_speed,
                             get_unit(data->units, WIND_SPEED));
     g_free(wind_speed);
     g_free(wind_direction);
-    g_free(rawvalue);
     label = gtk_label_new(value);
     if (!(day % 2))
         gtk_widget_modify_fg(GTK_WIDGET(label), GTK_STATE_NORMAL, &black);
@@ -820,7 +915,8 @@ make_forecast(plugin_data *data)
     const GdkColor lightbg = {0, 0xeaea, 0xeaea, 0xeaea};
     const GdkColor darkbg = {0, 0x6666, 0x6666, 0x6666};
     GArray *daydata;
-    gchar *dayname;
+    xml_astro *astro;
+    gchar *dayname, *text;
     gint i;
     daytime daytime;
 
@@ -853,6 +949,11 @@ make_forecast(plugin_data *data)
             ebox = add_forecast_header(dayname, 90.0, &darkbg);
         g_free(dayname);
 
+        /* add tooltip to forecast day header */
+        astro = get_astro_data_for_day(data->astrodata, i);
+        text = forecast_day_header_tooltip_text(astro);
+        gtk_widget_set_tooltip_markup(GTK_WIDGET(ebox), text);
+
         if (data->forecast_layout == FC_LAYOUT_CALENDAR)
             gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(ebox),
                                       i+1, i+2, 0, 1);
@@ -905,7 +1006,7 @@ create_forecast_tab(plugin_data *data)
      * maximum height we may use, subtracting some sane value just to
      * be on the safe side. */
     window = GDK_WINDOW(gtk_widget_get_window(GTK_WIDGET(data->iconimage)));
-    screen = GDK_SCREEN(gdk_window_get_screen(window));
+    screen = GDK_SCREEN(gtk_widget_get_screen(GTK_WIDGET(data->iconimage)));
     if (G_LIKELY(window && screen))
         monitor_num = gdk_screen_get_monitor_at_window(screen, window);
     gdk_screen_get_monitor_geometry(screen, monitor_num, &rect);
@@ -1005,7 +1106,7 @@ update_summary_subtitle(plugin_data *data)
 
     time(&now_t);
 #ifdef HAVE_UPOWER_GLIB
-    if (data->upower_on_battery || data->upower_lid_closed)
+    if (data->upower_on_battery)
         date_format = "%Y-%m-%d %H:%M %z (%Z)";
     else
 #endif
@@ -1021,11 +1122,11 @@ update_summary_subtitle(plugin_data *data)
     g_get_current_time(&now);
     now_ms = ((gint64) now.tv_sec * 1000) + ((gint64) now.tv_usec / 1000);
 #ifdef HAVE_UPOWER_GLIB
-    if (data->upower_on_battery || data->upower_lid_closed)
-        update_interval = 60000 - (now_ms % 60000) + 1;
+    if (data->upower_on_battery)
+        update_interval = 60000 - (now_ms % 60000) + 10;
     else
 #endif
-        update_interval = 1000 - (now_ms % 1000) + 1;
+        update_interval = 1000 - (now_ms % 1000) + 10;
     data->summary_update_timer =
         g_timeout_add(update_interval, (GSourceFunc) update_summary_subtitle,
                       data);
